@@ -36,4 +36,16 @@ logLik.gdm <- function (object, ...) {
     class(out) <- "logLik"
     out
 }
-#############################################
\ No newline at end of file
+#############################################
+#########################################
+# mcdina class
+logLik.mcdina <- function (object, ...) {
+	# extract log-likelihood
+	out <- object$loglike
+    # number of parameters
+    attr(out, "df") <- sum( object$Npars )
+	# extract number of observations
+    attr(out, "nobs") <- nrow(object$I)
+    class(out) <- "logLik"
+    out
+}
\ No newline at end of file
